@@ -1,6 +1,6 @@
 package Catmandu::RIS;
 
-our $VERSION = '0.04';
+our $VERSION = '0.10';
 
 1;
 __END__
@@ -21,6 +21,16 @@ Catmandu::RIS -  Catmandu modules for working with RIS data
 
 =end markdown
 
+=head1 SYNOPSIS
+
+  catmandu convert RIS < input.txt
+  
+  # Use the --human option to translate RIS tags into human readable strings
+  catmandu convert RIS --human 1 < input.txt
+
+  # Provide a comma separated mapping file to translate RIS tags
+  catmandu convert RIS --human mappings/my_tags.txt < input.txt
+
 =head1 Author
 
 Nicolas Steenlant
@@ -29,6 +39,8 @@ Nicolas Steenlant
 
 Vitali Peil
 
+Patrick Hochstenbach
+
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
